@@ -28,6 +28,7 @@ v_next_partition_name           text;
 v_next_partition_timestamp      timestamptz;
 v_parent_schema                 text;
 v_parent_tablename              text;
+v_partition_expression          text;
 v_partition_interval            interval;
 v_prev_partition_name           text;
 v_prev_partition_timestamp      timestamptz;
@@ -94,6 +95,11 @@ AND tablename = split_part(p_parent_table, '.', 2)::name;
 
 v_function_name := @extschema@.check_name_length(v_parent_tablename, '_part_trig_func', FALSE);
 
+v_partition_expression := case
+    when v_epoch = true then format('to_timestamp(NEW.%I)', v_control)
+    else format('NEW.%I', v_control)
+end;
+
 IF v_type = 'time' THEN
     v_trig_func := format('CREATE OR REPLACE FUNCTION %I.%I() RETURNS trigger LANGUAGE plpgsql AS $t$
             DECLARE
@@ -106,97 +112,56 @@ IF v_type = 'time' THEN
     , v_parent_schema
     , v_function_name);
 
-    IF v_epoch = false THEN
-        CASE
-            WHEN v_partition_interval = '15 mins' THEN 
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', NEW.%I) + 
-                    ''15min''::interval * floor(date_part(''minute'', NEW.%I) / 15.0);' , v_control , v_control);
-                v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP) + 
-                    '15min'::interval * floor(date_part('minute', CURRENT_TIMESTAMP) / 15.0);
-            WHEN v_partition_interval = '30 mins' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', NEW.%I) + 
-                    ''30min''::interval * floor(date_part(''minute'', NEW.%I) / 30.0);' , v_control , v_control);
-                v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP) + 
-                    '30min'::interval * floor(date_part('minute', CURRENT_TIMESTAMP) / 30.0);
-            WHEN v_partition_interval = '1 hour' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', NEW.%I);', v_control);
-                v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP);
-             WHEN v_partition_interval = '1 day' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''day'', NEW.%I);', v_control);
-                v_current_partition_timestamp := date_trunc('day', CURRENT_TIMESTAMP);
-            WHEN v_partition_interval = '1 week' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''week'', NEW.%I);', v_control);
-                v_current_partition_timestamp := date_trunc('week', CURRENT_TIMESTAMP);
-            WHEN v_partition_interval = '1 month' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''month'', NEW.%I);', v_control);
-                v_current_partition_timestamp := date_trunc('month', CURRENT_TIMESTAMP);
-            WHEN v_partition_interval = '3 months' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''quarter'', NEW.%I);', v_control);
-                v_current_partition_timestamp := date_trunc('quarter', CURRENT_TIMESTAMP);
-            WHEN v_partition_interval = '1 year' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''year'', NEW.%I);', v_control);
-                v_current_partition_timestamp := date_trunc('year', CURRENT_TIMESTAMP);
-        END CASE;
-    ELSE -- epoch is true
-        CASE
-            WHEN v_partition_interval = '15 mins' THEN 
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', to_timestamp(NEW.%I)) + 
-                    ''15min''::interval * floor(date_part(''minute'', NEW.%I) / 15.0);' , v_control , v_control);
-                v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP) + 
-                    '15min'::interval * floor(date_part('minute', CURRENT_TIMESTAMP) / 15.0);
-            WHEN v_partition_interval = '30 mins' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', to_timestamp(NEW.%I)) + 
-                    ''30min''::interval * floor(date_part(''minute'', NEW.%I) / 30.0);' , v_control , v_control);
-                v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP) + 
-                    '30min'::interval * floor(date_part('minute', CURRENT_TIMESTAMP) / 30.0);
-            WHEN v_partition_interval = '1 hour' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', to_timestamp(NEW.%I));', v_control);
-                v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP);
-             WHEN v_partition_interval = '1 day' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''day'', to_timestamp(NEW.%I));', v_control);
-                v_current_partition_timestamp := date_trunc('day', CURRENT_TIMESTAMP);
-            WHEN v_partition_interval = '1 week' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''week'', to_timestamp(NEW.%I));', v_control);
-                v_current_partition_timestamp := date_trunc('week', CURRENT_TIMESTAMP);
-            WHEN v_partition_interval = '1 month' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''month'', to_timestamp(NEW.%I));', v_control);
-                v_current_partition_timestamp := date_trunc('month', CURRENT_TIMESTAMP);
-            WHEN v_partition_interval = '3 months' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''quarter'', to_timestamp(NEW.%I));', v_control);
-                v_current_partition_timestamp := date_trunc('quarter', CURRENT_TIMESTAMP);
-            WHEN v_partition_interval = '1 year' THEN
-                v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''year'', to_timestamp(NEW.%I));', v_control);
-                v_current_partition_timestamp := date_trunc('year', CURRENT_TIMESTAMP);
-        END CASE;
-    END IF;
+    CASE
+        WHEN v_partition_interval = '15 mins' THEN
+            v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', %s) +
+                ''15min''::interval * floor(date_part(''minute'', %1$s) / 15.0);' , v_partition_expression);
+            v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP) +
+                '15min'::interval * floor(date_part('minute', CURRENT_TIMESTAMP) / 15.0);
+        WHEN v_partition_interval = '30 mins' THEN
+            v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', %s) +
+                ''30min''::interval * floor(date_part(''minute'', %1$s) / 30.0);' , v_partition_expression);
+            v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP) +
+                '30min'::interval * floor(date_part('minute', CURRENT_TIMESTAMP) / 30.0);
+        WHEN v_partition_interval = '1 hour' THEN
+            v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''hour'', %s);', v_partition_expression);
+            v_current_partition_timestamp := date_trunc('hour', CURRENT_TIMESTAMP);
+         WHEN v_partition_interval = '1 day' THEN
+            v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''day'', %s);', v_partition_expression);
+            v_current_partition_timestamp := date_trunc('day', CURRENT_TIMESTAMP);
+        WHEN v_partition_interval = '1 week' THEN
+            v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''week'', %s);', v_partition_expression);
+            v_current_partition_timestamp := date_trunc('week', CURRENT_TIMESTAMP);
+        WHEN v_partition_interval = '1 month' THEN
+            v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''month'', %s);', v_partition_expression);
+            v_current_partition_timestamp := date_trunc('month', CURRENT_TIMESTAMP);
+        WHEN v_partition_interval = '3 months' THEN
+            v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''quarter'', %s);', v_partition_expression);
+            v_current_partition_timestamp := date_trunc('quarter', CURRENT_TIMESTAMP);
+        WHEN v_partition_interval = '1 year' THEN
+            v_trig_func := v_trig_func||format('v_partition_timestamp := date_trunc(''year'', %s);', v_partition_expression);
+            v_current_partition_timestamp := date_trunc('year', CURRENT_TIMESTAMP);
+    END CASE;
 
     v_current_partition_name := @extschema@.check_name_length(v_parent_tablename, to_char(v_current_partition_timestamp, v_datetime_string), TRUE); 
     v_next_partition_timestamp := v_current_partition_timestamp + v_partition_interval::interval;
 
-    IF v_epoch = false THEN
-        v_trig_func := v_trig_func ||format('
-            IF NEW.%I >= %L AND NEW.%I < %L THEN '
-                , v_control
-                , v_current_partition_timestamp
-                , v_control
-                , v_next_partition_timestamp);
+    v_trig_func := v_trig_func ||format('
+            IF %s >= %L AND %1$s < %3$L THEN '
+            , v_partition_expression
+            , v_current_partition_timestamp
+            , v_next_partition_timestamp);
+
+    SELECT count(*) INTO v_count FROM pg_catalog.pg_tables WHERE schemaname = v_parent_schema::name AND tablename = v_current_partition_name::name;
+    IF v_count > 0 THEN
+        v_trig_func := v_trig_func || format('
+            INSERT INTO %I.%I VALUES (NEW.*) %s; ', v_parent_schema, v_current_partition_name, v_upsert);
     ELSE
-        v_trig_func := v_trig_func ||format('
-            IF to_timestamp(NEW.%I) >= %L AND to_timestamp(NEW.%I) < %L THEN '
-                , v_control
-                , v_current_partition_timestamp
-                , v_control
-                , v_next_partition_timestamp);
+        v_trig_func := v_trig_func || '
+            -- Child table for current values does not exist in this partition set, so write to parent
+            RETURN NEW;';
     END IF;
-        SELECT count(*) INTO v_count FROM pg_catalog.pg_tables WHERE schemaname = v_parent_schema::name AND tablename = v_current_partition_name::name;
-        IF v_count > 0 THEN
-            v_trig_func := v_trig_func || format('
-                INSERT INTO %I.%I VALUES (NEW.*) %s; ', v_parent_schema, v_current_partition_name, v_upsert);
-        ELSE
-            v_trig_func := v_trig_func || '
-                -- Child table for current values does not exist in this partition set, so write to parent
-                RETURN NEW;';
-        END IF;
+
     FOR i IN 1..v_optimize_trigger LOOP
         v_prev_partition_timestamp := v_current_partition_timestamp - (v_partition_interval::interval * i);
         v_next_partition_timestamp := v_current_partition_timestamp + (v_partition_interval::interval * i);
@@ -208,55 +173,27 @@ IF v_type = 'time' THEN
         -- Handles optimize_trigger being larger than premake (to go back in time further) and edge case of changing optimize_trigger immediately after running create_parent().
         SELECT count(*) INTO v_count FROM pg_catalog.pg_tables WHERE schemaname = v_parent_schema::name AND tablename = v_prev_partition_name::name;
         IF v_count > 0 THEN
-            IF v_epoch = false THEN
-                v_trig_func := v_trig_func ||format('
-            ELSIF NEW.%I >= %L AND NEW.%I < %L THEN 
+            v_trig_func := v_trig_func ||format('
+            ELSIF %s >= %L AND %1$s < %3$L THEN 
                 INSERT INTO %I.%I VALUES (NEW.*) %s;'
-                    , v_control
-                    , v_prev_partition_timestamp
-                    , v_control
-                    , v_prev_partition_timestamp + v_partition_interval::interval
-                    , v_parent_schema
-                    , v_prev_partition_name
-                    , v_upsert);
-            ELSE
-                v_trig_func := v_trig_func ||format('
-            ELSIF to_timestamp(NEW.%I) >= %L AND to_timestamp(NEW.%I) < %L THEN 
-                INSERT INTO %I.%I VALUES (NEW.*) %s;'
-                    , v_control
-                    , v_prev_partition_timestamp
-                    , v_control
-                    , v_prev_partition_timestamp + v_partition_interval::interval
-                    , v_parent_schema
-                    , v_prev_partition_name
-                    , v_upsert);
-            END IF;
+                , v_partition_expression
+                , v_prev_partition_timestamp
+                , v_prev_partition_timestamp + v_partition_interval::interval
+                , v_parent_schema
+                , v_prev_partition_name
+                , v_upsert);
         END IF;
         SELECT count(*) INTO v_count FROM pg_catalog.pg_tables WHERE schemaname = v_parent_schema::name AND tablename = v_next_partition_name::name;
         IF v_count > 0 THEN
-            IF v_epoch = false THEN
-                v_trig_func := v_trig_func ||format(' 
-            ELSIF NEW.%I >= %L AND NEW.%I < %L THEN 
+            v_trig_func := v_trig_func ||format(' 
+            ELSIF %s >= %L AND %1$s < %3$L THEN 
                 INSERT INTO %I.%I VALUES (NEW.*) %s;'
-                    , v_control
-                    , v_next_partition_timestamp
-                    , v_control
-                    , v_final_partition_timestamp
-                    , v_parent_schema
-                    , v_next_partition_name
-                    , v_upsert);
-            ELSE
-                v_trig_func := v_trig_func ||format(' 
-            ELSIF to_timestamp(NEW.%I) >= %L AND to_timestamp(NEW.%I) < %L THEN 
-                INSERT INTO %I.%I VALUES (NEW.*) %s;'
-                    , v_control
-                    , v_next_partition_timestamp
-                    , v_control
-                    , v_final_partition_timestamp
-                    , v_parent_schema
-                    , v_next_partition_name
-                    , v_upsert);
-            END IF;
+                , v_partition_expression
+                , v_next_partition_timestamp
+                , v_final_partition_timestamp
+                , v_parent_schema
+                , v_next_partition_name
+                , v_upsert);
         END IF;
 
     END LOOP;
@@ -318,32 +255,16 @@ ELSIF v_type = 'time-custom' THEN
         , v_parent_schema
         , v_function_name);
 
-    IF v_epoch = false THEN
-        v_trig_func := v_trig_func || format(' 
-
+    v_trig_func := v_trig_func || format(' 
         SELECT c.child_table, p.upsert INTO v_child_table, v_upsert
         FROM @extschema@.custom_time_partitions c
         JOIN @extschema@.part_config p ON c.parent_table = p.parent_table
-        WHERE c.partition_range @> NEW.%I 
+        WHERE c.partition_range @> %s 
         AND c.parent_table = %L;'
-        , v_control
+        , v_partition_expression
         , v_parent_schema||'.'||v_parent_tablename);
 
-    ELSE -- epoch true
-        v_trig_func := v_trig_func || format(' 
-
-        SELECT c.child_table, p.upsert INTO v_child_table, v_upsert
-        FROM @extschema@.custom_time_partitions c
-        JOIN @extschema@.part_config p ON c.parent_table = p.parent_table
-        WHERE c.partition_range @> to_timestamp(NEW.%I)
-        AND c.parent_table = %L;'
-        , v_control
-        , v_parent_schema||'.'||v_parent_tablename);
-
-    END IF;
-
     v_trig_func := v_trig_func || '
-
         SELECT schemaname, tablename INTO v_child_schemaname, v_child_tablename 
         FROM pg_catalog.pg_tables 
         WHERE schemaname = split_part(v_child_table, ''.'', 1)::name
