@@ -21,7 +21,6 @@ v_create_count                  int := 0;
 v_current_partition             text;
 v_current_partition_id          bigint;
 v_current_partition_timestamp   timestamptz;
-v_datetime_string               text;
 v_drop_count                    int := 0;
 v_job_id                        bigint;
 v_jobmon                        boolean;
@@ -38,6 +37,7 @@ v_next_partition_timestamp      timestamptz;
 v_old_search_path               text;
 v_parent_schema                 text;
 v_parent_tablename              text;
+v_partition_expression          text;
 v_premade_count                 int;
 v_premake_id_max                bigint;
 v_premake_id_min                bigint;
@@ -88,7 +88,6 @@ v_tables_list_sql := 'SELECT parent_table
                 , partition_interval
                 , control
                 , premake
-                , datetime_string
                 , undo_in_progress
                 , sub_partition_set_full
                 , epoch
@@ -127,6 +126,14 @@ LOOP
     WHERE schemaname = split_part(v_row.parent_table, '.', 1)::name
     AND tablename = split_part(v_row.parent_table, '.', 2)::name;
 
+    v_partition_expression := case
+        when v_row.epoch = true then format('to_timestamp(%I)', v_row.control)
+        else format('%I', v_row.control)
+    end;
+    IF p_debug THEN
+        RAISE NOTICE 'run_maint: v_partition_expression: %', v_partition_expression;
+    END IF;
+
     SELECT partition_tablename INTO v_last_partition FROM @extschema@.show_partitions(v_row.parent_table, 'DESC') LIMIT 1;
     IF p_debug THEN
         RAISE NOTICE 'run_maint: parent_table: %, v_last_partition: %', v_row.parent_table, v_last_partition;
@@ -142,19 +149,11 @@ LOOP
         FOR v_row_max_time IN
             SELECT partition_schemaname, partition_tablename FROM @extschema@.show_partitions(v_row.parent_table, 'DESC')
         LOOP
-            IF v_row.epoch = false THEN
-                EXECUTE format('SELECT max(%I)::text FROM %I.%I'
-                                    , v_row.control
-                                    , v_row_max_time.partition_schemaname
-                                    , v_row_max_time.partition_tablename
-                                ) INTO v_current_partition_timestamp;
-            ELSE
-                EXECUTE format('SELECT to_timestamp(max(%I))::text FROM %I.%I'
-                                    , v_row.control
-                                    , v_row_max_time.partition_schemaname
-                                    , v_row_max_time.partition_tablename
-                                ) INTO v_current_partition_timestamp;
-            END IF;
+            EXECUTE format('SELECT max(%s)::text FROM %I.%I'
+                                , v_partition_expression
+                                , v_row_max_time.partition_schemaname
+                                , v_row_max_time.partition_tablename
+                            ) INTO v_current_partition_timestamp;
             IF v_current_partition_timestamp IS NOT NULL THEN
                 SELECT suffix_timestamp INTO v_current_partition_timestamp FROM @extschema@.show_partition_name(v_row.parent_table, v_current_partition_timestamp::text);
                 EXIT;
@@ -162,11 +161,7 @@ LOOP
         END LOOP;
         -- Check for values in the parent table. If they are there and greater than all child values, use that instead
         -- This allows maintenance to continue working properly if there is a large gap in data insertion. Data will remain in parent, but new tables will be created
-        IF v_row.epoch = false THEN
-            EXECUTE format('SELECT max(%I) FROM ONLY %I.%I', v_row.control, v_parent_schema, v_parent_tablename) INTO v_max_time_parent;
-        ELSE
-            EXECUTE format('SELECT to_timestamp(max(%I)) FROM ONLY %I.%I', v_row.control, v_parent_schema, v_parent_tablename) INTO v_max_time_parent;
-        END IF;
+        EXECUTE format('SELECT max(%s) FROM ONLY %I.%I', v_partition_expression, v_parent_schema, v_parent_tablename) INTO v_max_time_parent;
         IF p_debug THEN
             RAISE NOTICE 'run_maint: v_current_partition_timestamp: %, v_max_time_parent: %', v_current_partition_timestamp, v_max_time_parent;
         END IF;
@@ -364,4 +359,3 @@ HINT: %', ex_message, ex_context, ex_detail, ex_hint;
 END
 $$;
 
-
