@@ -94,3 +94,33 @@ ALTER TABLE @extschema@.part_config ADD CONSTRAINT control_constraint_col_chk CH
 ALTER TABLE @extschema@.part_config_sub ADD CONSTRAINT control_constraint_col_chk CHECK ((sub_constraint_cols @> ARRAY[sub_control]) <> true);
 
 
+/*
+ * Custom view to help improve privilege lookups for pg_partman. 
+ * information_schema is a performance bottleneck since indexes aren't being used properly.
+ */
+CREATE VIEW @extschema@.table_privs AS
+    SELECT u_grantor.rolname AS grantor,
+           grantee.rolname AS grantee,
+           nc.nspname AS table_schema,
+           c.relname AS table_name,
+           c.prtype AS privilege_type
+    FROM (
+            SELECT oid, relname, relnamespace, relkind, relowner, (aclexplode(coalesce(relacl, acldefault('r', relowner)))).* FROM pg_class
+         ) AS c (oid, relname, relnamespace, relkind, relowner, grantor, grantee, prtype, grantable),
+         pg_namespace nc,
+         pg_authid u_grantor,
+         (
+           SELECT oid, rolname FROM pg_authid
+           UNION ALL
+           SELECT 0::oid, 'PUBLIC'
+         ) AS grantee (oid, rolname)
+    WHERE c.relnamespace = nc.oid
+          AND c.relkind IN ('r', 'v')
+          AND c.grantee = grantee.oid
+          AND c.grantor = u_grantor.oid
+          AND c.prtype IN ('INSERT', 'SELECT', 'UPDATE', 'DELETE', 'TRUNCATE', 'REFERENCES', 'TRIGGER')
+          AND (pg_has_role(u_grantor.oid, 'USAGE')
+               OR pg_has_role(grantee.oid, 'USAGE')
+               OR grantee.rolname = 'PUBLIC' );
+
+
